@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 from uuid import uuid4
 
 from django.conf import settings
@@ -8,11 +9,11 @@ from django.utils.translation import ugettext_lazy as _
 from . import factory
 
 DEFAULT_PAYMENT_STATUS_CHOICES = (
-    ('waiting', _(u'Waiting for confirmation')),
-    ('confirmed', _(u'Confirmed')),
-    ('rejected', _(u'Rejected')),
-    ('error', _(u'Error')),
-    ('input', _(u'Input'))
+    ('waiting', _('Waiting for confirmation')),
+    ('confirmed', _('Confirmed')),
+    ('rejected', _('Rejected')),
+    ('error', _('Error')),
+    ('input', _('Input'))
 )
 PAYMENT_STATUS_CHOICES = getattr(settings, 'PAYMENT_STATUS_CHOICES',
                                  DEFAULT_PAYMENT_STATUS_CHOICES)
